@@ -1,5 +1,5 @@
 /*
- *   Copyright (C) 2009-2017 Erwin Waterlander
+ *   Copyright (C) 2009-2018 Erwin Waterlander
  *   All rights reserved.
  *
  *   Redistribution and use in source and binary forms, with or without
@@ -227,11 +227,13 @@ void d2u_utf8_fprintf( FILE *stream, const char* format, ... ) {
           BOM_printed = 1;
       }
       fwprintf(stream,L"%S",buf);
+      fflush(stream);
       SetConsoleOutputCP(outputCP);
 
    /* The following UTF-8 method does not give correct output. I don't know why. */
    /*prevmode = _setmode(_fileno(stream), _O_U8TEXT);
      fwprintf(stream,L"%S",buf);
+     fflush(stream);
      _setmode(_fileno(stream), prevmode); */
 
    } else if ((d2u_display_encoding == D2U_DISPLAY_UNICODE) || (d2u_display_encoding == D2U_DISPLAY_UNICODEBOM)) {
@@ -981,6 +983,7 @@ FILE* MakeTempFileFrom(const char *OutFN, char **fname_ret)
   *fname_ret = fname_str;
 
   free(cpy);
+  cpy = NULL;
 
 #ifdef NO_MKSTEMP
   if ((name = d2u_mktemp(fname_str)) == NULL)
@@ -999,6 +1002,10 @@ FILE* MakeTempFileFrom(const char *OutFN, char **fname_ret)
   return (fp);
 
   make_failed:
+    if (cpy) {
+       free(cpy);
+       cpy = NULL;
+    }
     free(*fname_ret);
     *fname_ret = NULL;
     return NULL;
@@ -1976,7 +1983,7 @@ void printInfo(CFlag *ipFlag, const char *filename, int bomtype, unsigned int lb
       D2U_UTF8_FPRINTF(stdout, "FILE");
     }
     if (ipFlag->file_info & INFO_PRINT0)
-      fputc(0, stdout);
+      (void) fputc(0, stdout);
     else
       D2U_UTF8_FPRINTF(stdout, "\n");
     header_done = 1;
@@ -2007,7 +2014,7 @@ void printInfo(CFlag *ipFlag, const char *filename, int bomtype, unsigned int lb
     D2U_UTF8_FPRINTF(stdout, "%s",ptr);
   }
   if (ipFlag->file_info & INFO_PRINT0)
-    fputc(0, stdout);
+    (void) fputc(0, stdout);
   else
     D2U_UTF8_FPRINTF(stdout, "\n");
 }
