@@ -203,6 +203,7 @@
 #define INFO_CONVERT 0x20
 #define INFO_HEADER  0x40
 #define INFO_NOPATH  0x80
+#define INFO_PRINT0  0x100
 
 #define SYMLINK_SKIP 0
 #define SYMLINK_FOLLOW 1
@@ -234,6 +235,7 @@ typedef struct
   int FromToMode;                       /* 0: dos2unix/unix2dos, 1: mac2unix/unix2mac */
   int NewLine;                          /* if TRUE, then additional newline */
   int Force;                            /* if TRUE, force conversion of all files. */
+  int AllowChown;                       /* if TRUE, allow file ownership change in old file mode. */
   int Follow;                           /* 0: skip symlink, 1: follow symbolic link, 2: replace symlink. */
   int status;
   int stdio_mode;                       /* if TRUE, stdio mode */
@@ -300,6 +302,7 @@ wint_t d2u_getwc(FILE *f, int bomtype);
 wint_t d2u_ungetwc(wint_t wc, FILE *f, int bomtype);
 wint_t d2u_putwc(wint_t wc, FILE *f, CFlag *ipFlag, const char *progname);
 #endif
+char *d2u_strncpy(char *dest, const char *src, size_t dest_size);
 
 #ifdef D2U_UNIFILE
 #define UNICODE
