@@ -8,7 +8,7 @@
  *  See also http://www.freebsd.org/copyright/freebsd-license.html
  *  --------
  *
- *  Copyright (C) 2009-2016 Erwin Waterlander
+ *  Copyright (C) 2009-2018 Erwin Waterlander
  *  Copyright (C) 1994-1995 Benjamin Lin.
  *  All rights reserved.
  *
@@ -477,6 +477,7 @@ int main (int argc, char *argv[])
   CFlag *pFlag;
   char *ptr;
   char localedir[1024];
+  int ret;
 # ifdef __MINGW64__
   int _dowildcard = -1; /* enable wildcard expansion for Win64 */
 # endif
@@ -566,9 +567,11 @@ int main (int argc, char *argv[])
 #endif
 
 #ifdef D2U_UNICODE
-  return parse_options(argc_new, argv_new, pFlag, localedir, progname, PrintLicense, ConvertUnixToDos, ConvertUnixToDosW);
+  ret = parse_options(argc_new, argv_new, pFlag, localedir, progname, PrintLicense, ConvertUnixToDos, ConvertUnixToDosW);
 #else
-  return parse_options(argc_new, argv_new, pFlag, localedir, progname, PrintLicense, ConvertUnixToDos);
+  ret = parse_options(argc_new, argv_new, pFlag, localedir, progname, PrintLicense, ConvertUnixToDos);
 #endif
+  free(pFlag);
+  return ret;
 }
 
